@@ -1,6 +1,6 @@
 /*
  * This file is part of dm-writeboost
- * Copyright (C) 2012-2018 Akira Hayakawa <ruby.wktk@gmail.com>
+ * Copyright (C) 2012-2023 Akira Hayakawa <ruby.wktk@gmail.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -21,6 +21,9 @@
 #include "dm-writeboost-metadata.h"
 #include "dm-writeboost-daemon.h"
 
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(5,7,0)
+#include <linux/part_stat.h>
+#endif
 #include <linux/rbtree.h>
 
 /*----------------------------------------------------------------------------*/
@@ -59,7 +62,7 @@ static void process_deferred_barriers(struct wb_device *wb, struct rambuffer *ra
 		struct bio *bio;
 
 		/* Make all the preceding data persistent. */
-		int err = blkdev_issue_flush(wb->cache_dev->bdev, GFP_NOIO, NULL);
+		int err = dm_blkdev_issue_flush(wb->cache_dev->bdev, GFP_NOIO);
 
 		/* Ack the chained barrier requests. */
 		while ((bio = bio_list_pop(&rambuf->barrier_ios)))
@@ -375,7 +378,7 @@ static bool do_writeback_segs(struct wb_device *wb)
 	if (!try_writeback_segs(wb))
 		return false;
 
-	blkdev_issue_flush(wb->backing_dev->bdev, GFP_NOIO, NULL);
+	dm_blkdev_issue_flush(wb->backing_dev->bdev, GFP_NOIO);
 	return true;
 }
 
@@ -478,12 +481,16 @@ int writeback_modulator_proc(void *data)
 {
 	struct wb_device *wb = data;
 
-	struct hd_struct *hd = wb->backing_dev->bdev->bd_part;
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(5,11,0)
+	struct block_device *part = wb->backing_dev->bdev;
+#else
+	struct hd_struct *part = wb->backing_dev->bdev->bd_part;
+#endif
 	unsigned long old = 0, new, util;
 	unsigned long intvl = 1000;
 
 	while (!kthread_should_stop()) {
-		new = jiffies_to_msecs(part_stat_read(hd, io_ticks));
+		new = jiffies_to_msecs(part_stat_read(part, io_ticks));
 
 		util = div_u64(100 * (new - old), 1000);
 
@@ -575,7 +582,7 @@ int data_synchronizer_proc(void *data)
 		}
 
 		flush_current_buffer(wb);
-		blkdev_issue_flush(wb->cache_dev->bdev, GFP_NOIO, NULL);
+		dm_blkdev_issue_flush(wb->cache_dev->bdev, GFP_NOIO);
 		schedule_timeout_interruptible(msecs_to_jiffies(intvl));
 	}
 	return 0;
