@@ -1,6 +1,6 @@
 /*
  * This file is part of dm-writeboost
- * Copyright (C) 2012-2018 Akira Hayakawa <ruby.wktk@gmail.com>
+ * Copyright (C) 2012-2023 Akira Hayakawa <ruby.wktk@gmail.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -438,13 +438,10 @@ static void zeroing_complete(int read_err, unsigned long write_err, void *contex
  */
 static int do_zeroing_region(struct wb_device *wb, struct dm_io_region *region)
 {
-	int err;
 	struct zeroing_context zc;
 	zc.error = 0;
 	init_completion(&zc.complete);
-	err = dm_kcopyd_zero(wb->copier, 1, region, 0, zeroing_complete, &zc);
-	if (err)
-		return err;
+	dm_kcopyd_zero(wb->copier, 1, region, 0, zeroing_complete, &zc);
 	wait_for_completion(&zc.complete);
 	return zc.error;
 }
@@ -510,7 +507,7 @@ static int format_all_segment_headers(struct wb_device *wb)
 		goto bad;
 	}
 
-	err = blkdev_issue_flush(dev->bdev, GFP_KERNEL, NULL);
+	err = dm_blkdev_issue_flush(dev->bdev, GFP_KERNEL);
 
 bad:
 	mempool_free(buf, wb->buf_8_pool);
@@ -984,7 +981,7 @@ static int infer_last_writeback_id(struct wb_device *wb)
 	u64 inferred_last_writeback_id;
 	u64 record_id;
 
-	struct superblock_record_device uninitialized_var(record);
+	struct superblock_record_device record;
 	err = read_superblock_record(&record, wb);
 	if (err)
 		return err;
