@@ -3,7 +3,7 @@
  * Log-structured Caching for Linux
  *
  * This file is part of dm-writeboost
- * Copyright (C) 2012-2018 Akira Hayakawa <ruby.wktk@gmail.com>
+ * Copyright (C) 2012-2023 Akira Hayakawa <ruby.wktk@gmail.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -424,13 +424,13 @@ static void inc_stat(struct wb_device *wb,
 
 	int i = 0;
 	if (rw)
-		i |= (1 << STAT_WRITE);
+		i |= (1 << WB_STAT_WRITE);
 	if (found)
-		i |= (1 << STAT_HIT);
+		i |= (1 << WB_STAT_HIT);
 	if (on_buffer)
-		i |= (1 << STAT_ON_BUFFER);
+		i |= (1 << WB_STAT_ON_BUFFER);
 	if (fullsize)
-		i |= (1 << STAT_FULLSIZE);
+		i |= (1 << WB_STAT_FULLSIZE);
 
 	v = &wb->stat[i];
 	atomic64_inc(v);
@@ -1837,7 +1837,7 @@ static void writeboost_postsuspend(struct dm_target *ti)
 {
 	struct wb_device *wb = ti->private;
 	flush_current_buffer(wb);
-	blkdev_issue_flush(wb->cache_dev->bdev, GFP_NOIO, NULL);
+	dm_blkdev_issue_flush(wb->cache_dev->bdev, GFP_NOIO);
 }
 
 #if LINUX_VERSION_CODE >= KERNEL_VERSION(4,17,0)
@@ -1942,12 +1942,18 @@ static void writeboost_status(struct dm_target *ti, status_type_t type,
 		for (i = 0; i < wb->nr_ctr_args; i++)
 			DMEMIT(" %s", wb->ctr_args[i]);
 		break;
+
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(5,15,0)
+	case STATUSTYPE_IMA:
+		*result = '\0';
+		break;
+#endif
 	}
 }
 
 static struct target_type writeboost_target = {
 	.name = "writeboost",
-	.version = {2, 2, 9},
+	.version = {2, 2, 15},
 	.module = THIS_MODULE,
 	.map = writeboost_map,
 	.end_io = writeboost_end_io,
