@@ -1,6 +1,6 @@
 /*
  * This file is part of dm-writeboost
- * Copyright (C) 2012-2018 Akira Hayakawa <ruby.wktk@gmail.com>
+ * Copyright (C) 2012-2023 Akira Hayakawa <ruby.wktk@gmail.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -232,10 +232,10 @@ struct read_cache_cells {
 /*----------------------------------------------------------------------------*/
 
 enum STATFLAG {
-	STAT_WRITE = 3, /* Write or read */
-	STAT_HIT = 2, /* Hit or miss */
-	STAT_ON_BUFFER = 1, /* Found on buffer or on the cache device */
-	STAT_FULLSIZE = 0, /* Bio is fullsize or partial */
+	WB_STAT_WRITE = 3, /* Write or read */
+	WB_STAT_HIT = 2, /* Hit or miss */
+	WB_STAT_ON_BUFFER = 1, /* Found on buffer or on the cache device */
+	WB_STAT_FULLSIZE = 0, /* Bio is fullsize or partial */
 };
 #define STATLEN (1 << 4)
 
@@ -502,13 +502,20 @@ sector_t dm_devsize(struct dm_dev *);
 
 /*----------------------------------------------------------------------------*/
 
-#if LINUX_VERSION_CODE >= KERNEL_VERSION(4,8,0)
-#define req_is_write(req) op_is_write((req)->bi_op)
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(6,0,0)
+#define req_is_write(req) op_is_write((req)->bi_opf)
+#define WB_IO_WRITE .bi_opf = REQ_OP_WRITE
+#define WB_IO_READ .bi_opf = REQ_OP_READ
+#define WB_IO_WRITE_FUA .bi_opf = REQ_OP_WRITE | REQ_FUA
 #define bio_is_barrier(bio) ((bio)->bi_opf & REQ_PREFLUSH)
 #define bio_is_fua(bio) ((bio)->bi_opf & REQ_FUA)
+#elif LINUX_VERSION_CODE >= KERNEL_VERSION(4,8,0)
+#define req_is_write(req) op_is_write((req)->bi_op)
 #define WB_IO_WRITE .bi_op = REQ_OP_WRITE, .bi_op_flags = 0
 #define WB_IO_READ .bi_op = REQ_OP_READ, .bi_op_flags = 0
 #define WB_IO_WRITE_FUA .bi_op = REQ_OP_WRITE, .bi_op_flags = REQ_FUA
+#define bio_is_barrier(bio) ((bio)->bi_opf & REQ_PREFLUSH)
+#define bio_is_fua(bio) ((bio)->bi_opf & REQ_FUA)
 #else
 #define req_is_write(req) ((req)->bi_rw == WRITE)
 #define bio_is_barrier(bio) ((bio)->bi_rw & REQ_FLUSH)
@@ -528,4 +535,12 @@ sector_t dm_devsize(struct dm_dev *);
 
 /*----------------------------------------------------------------------------*/
 
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(5,12,0)
+#define dm_blkdev_issue_flush(x, y) blkdev_issue_flush(x)
+#elif LINUX_VERSION_CODE >= KERNEL_VERSION(5,8,0)
+#define dm_blkdev_issue_flush(x, y) blkdev_issue_flush(x, y)
+#else
+#define dm_blkdev_issue_flush(x, y) blkdev_issue_flush(x, y, NULL)
+#endif
+
 #endif
